#ifndef LH754xx_h
#define LH754xx_h
#define UART0_DR (*(volatile unsigned long *)0xfffc0000)
#define UART0_RSR (*(volatile unsigned long *)0xfffc0004)
#define UART0_ECR (*(volatile unsigned long *)0xfffc0004)
#define UART0_FR (*(volatile unsigned long *)0xfffc0018)
#define UART0_IBRD (*(volatile unsigned long *)0xfffc0024)
#define UART0_FBRD (*(volatile unsigned long *)0xfffc0028)
#define UART0_LCR_H (*(volatile unsigned long *)0xfffc002c)
#define UART0_CTRL (*(volatile unsigned long *)0xfffc0030)
#define UART0_IFLS (*(volatile unsigned long *)0xfffc0034)
#define UART0_IMSC (*(volatile unsigned long *)0xfffc0038)
#define UART0_RIS (*(volatile unsigned long *)0xfffc003c)
#define UART0_MIS (*(volatile unsigned long *)0xfffc0040)
#define UART0_ICR (*(volatile unsigned long *)0xfffc0044)
#define UART0_DMACTRL (*(volatile unsigned long *)0xfffc0048)
#define UART1_DR (*(volatile unsigned long *)0xfffc1000)
#define UART1_RSR (*(volatile unsigned long *)0xfffc1004)
#define UART1_ECR (*(volatile unsigned long *)0xfffc1004)
#define UART1_FR (*(volatile unsigned long *)0xfffc1018)
#define UART1_IBRD (*(volatile unsigned long *)0xfffc1024)
#define UART1_FBRD (*(volatile unsigned long *)0xfffc1028)
#define UART1_LCR_H (*(volatile unsigned long *)0xfffc102c)
#define UART1_CTRL (*(volatile unsigned long *)0xfffc1030)
#define UART1_IFLS (*(volatile unsigned long *)0xfffc1034)
#define UART1_IMSC (*(volatile unsigned long *)0xfffc1038)
#define UART1_RIS (*(volatile unsigned long *)0xfffc103c)
#define UART1_MIS (*(volatile unsigned long *)0xfffc1040)
#define UART1_ICR (*(volatile unsigned long *)0xfffc1044)
#define UART1_DMACTRL (*(volatile unsigned long *)0xfffc1048)
#define UART2_TXD (*(volatile unsigned long *)0xfffc2000)
#define UART2_RXD (*(volatile unsigned long *)0xfffc2000)
#define UART2_BAL (*(volatile unsigned long *)0xfffc2000)
#define UART2_CLCF (*(volatile unsigned long *)0xfffc2000)
#define UART2_BBL (*(volatile unsigned long *)0xfffc2000)
#define UART2_BAH (*(volatile unsigned long *)0xfffc2004)
#define UART2_GER (*(volatile unsigned long *)0xfffc2004)
#define UART2_TXF (*(volatile unsigned long *)0xfffc2004)
#define UART2_RXF (*(volatile unsigned long *)0xfffc2004)
#define UART2_FMD (*(volatile unsigned long *)0xfffc2004)
#define UART2_BACF (*(volatile unsigned long *)0xfffc2004)
#define UART2_BBH (*(volatile unsigned long *)0xfffc2004)
#define UART2_GIR (*(volatile unsigned long *)0xfffc2008)
#define UART2_LCR (*(volatile unsigned long *)0xfffc200c)
#define UART2_TMCR (*(volatile unsigned long *)0xfffc200c)
#define UART2_TMST (*(volatile unsigned long *)0xfffc200c)
#define UART2_TMD (*(volatile unsigned long *)0xfffc200c)
#define UART2_BBCF (*(volatile unsigned long *)0xfffc200c)
#define UART2_MCR (*(volatile unsigned long *)0xfffc2010)
#define UART2_FLR (*(volatile unsigned long *)0xfffc2010)
#define UART2_IMD (*(volatile unsigned long *)0xfffc2010)
#define UART2_LSR (*(volatile unsigned long *)0xfffc2014)
#define UART2_RCM (*(volatile unsigned long *)0xfffc2014)
#define UART2_RST (*(volatile unsigned long *)0xfffc2014)
#define UART2_ACR1 (*(volatile unsigned long *)0xfffc2014)
#define UART2_RIE (*(volatile unsigned long *)0xfffc2018)
#define UART2_TMIE (*(volatile unsigned long *)0xfffc2018)
#define UART2_ACR0 (*(volatile unsigned long *)0xfffc201c)
#define UART2_ICM (*(volatile unsigned long *)0xfffc201c)
#define UART2_GSR (*(volatile unsigned long *)0xfffc201c)
#define UART2_RMD (*(volatile unsigned long *)0xfffc201c)
#define ADC_HW (*(volatile unsigned long *)0xfffc3000)
#define ADC_LW (*(volatile unsigned long *)0xfffc3004)
#define ADC_RR (*(volatile unsigned long *)0xfffc3008)
#define ADC_IM (*(volatile unsigned long *)0xfffc300c)
#define ADC_PC (*(volatile unsigned long *)0xfffc3010)
#define ADC_GC (*(volatile unsigned long *)0xfffc3014)
#define ADC_GS (*(volatile unsigned long *)0xfffc3018)
#define ADC_IS (*(volatile unsigned long *)0xfffc301c)
#define ADC_FS (*(volatile unsigned long *)0xfffc3020)
#define ADC_HWCB0 (*(volatile unsigned long *)0xfffc3024)
#define ADC_HWCB1 (*(volatile unsigned long *)0xfffc3028)
#define ADC_HWCB2 (*(volatile unsigned long *)0xfffc302c)
#define ADC_HWCB3 (*(volatile unsigned long *)0xfffc3030)
#define ADC_HWCB4 (*(volatile unsigned long *)0xfffc3034)
#define ADC_HWCB5 (*(volatile unsigned long *)0xfffc3038)
#define ADC_HWCB6 (*(volatile unsigned long *)0xfffc303c)
#define ADC_HWCB7 (*(volatile unsigned long *)0xfffc3040)
#define ADC_HWCB8 (*(volatile unsigned long *)0xfffc3044)
#define ADC_HWCB9 (*(volatile unsigned long *)0xfffc3048)
#define ADC_HWCB10 (*(volatile unsigned long *)0xfffc304c)
#define ADC_HWCB11 (*(volatile unsigned long *)0xfffc3050)
#define ADC_HWCB12 (*(volatile unsigned long *)0xfffc3054)
#define ADC_HWCB13 (*(volatile unsigned long *)0xfffc3058)
#define ADC_HWCB14 (*(volatile unsigned long *)0xfffc305c)
#define ADC_HWCB15 (*(volatile unsigned long *)0xfffc3060)
#define ADC_LWCB0 (*(volatile unsigned long *)0xfffc3064)
#define ADC_LWCB1 (*(volatile unsigned long *)0xfffc3068)
#define ADC_LWCB2 (*(volatile unsigned long *)0xfffc306c)
#define ADC_LWCB3 (*(volatile unsigned long *)0xfffc3070)
#define ADC_LWCB4 (*(volatile unsigned long *)0xfffc3074)
#define ADC_LWCB5 (*(volatile unsigned long *)0xfffc3078)
#define ADC_LWCB6 (*(volatile unsigned long *)0xfffc307c)
#define ADC_LWCB7 (*(volatile unsigned long *)0xfffc3080)
#define ADC_LWCB8 (*(volatile unsigned long *)0xfffc3084)
#define ADC_LWCB9 (*(volatile unsigned long *)0xfffc3088)
#define ADC_LWCB10 (*(volatile unsigned long *)0xfffc308c)
#define ADC_LWCB11 (*(volatile unsigned long *)0xfffc3090)
#define ADC_LWCB12 (*(volatile unsigned long *)0xfffc3094)
#define ADC_LWCB13 (*(volatile unsigned long *)0xfffc3098)
#define ADC_LWCB14 (*(volatile unsigned long *)0xfffc309c)
#define ADC_LWCB15 (*(volatile unsigned long *)0xfffc30a0)
#define ADC_IHWCTRL (*(volatile unsigned long *)0xfffc30a4)
#define ADC_ILWCTRL (*(volatile unsigned long *)0xfffc30a8)
#define ADC_MIS (*(volatile unsigned long *)0xfffc30ac)
#define ADC_IC (*(volatile unsigned long *)0xfffc30ac)
#define Timer0_CTRL (*(volatile unsigned long *)0xfffc4000)
#define Timer0_CMP_CAP_CTRL (*(volatile unsigned long *)0xfffc4004)
#define Timer0_INT_CTRL (*(volatile unsigned long *)0xfffc4008)
#define Timer0_STATUS (*(volatile unsigned long *)0xfffc400c)
#define Timer0_CNT (*(volatile unsigned long *)0xfffc4010)
#define Timer0_CMP0 (*(volatile unsigned long *)0xfffc4014)
#define Timer0_CMP1 (*(volatile unsigned long *)0xfffc4018)
#define Timer0_CAP0 (*(volatile unsigned long *)0xfffc401c)
#define Timer0_CAP1 (*(volatile unsigned long *)0xfffc4020)
#define Timer0_CAP2 (*(volatile unsigned long *)0xfffc4024)
#define Timer0_CAP3 (*(volatile unsigned long *)0xfffc4028)
#define Timer0_CAP4 (*(volatile unsigned long *)0xfffc402c)
#define Timer1_CTRL (*(volatile unsigned long *)0xfffc4030)
#define Timer1_INT_CTRL (*(volatile unsigned long *)0xfffc4034)
#define Timer1_STATUS (*(volatile unsigned long *)0xfffc4038)
#define Timer1_CNT (*(volatile unsigned long *)0xfffc403c)
#define Timer1_CMP0 (*(volatile unsigned long *)0xfffc4040)
#define Timer1_CMP1 (*(volatile unsigned long *)0xfffc4044)
#define Timer1_CAP0 (*(volatile unsigned long *)0xfffc4048)
#define Timer1_CAP1 (*(volatile unsigned long *)0xfffc404c)
#define Timer2_CTRL (*(volatile unsigned long *)0xfffc4050)
#define Timer2_INT_CTRL (*(volatile unsigned long *)0xfffc4054)
#define Timer2_STATUS (*(volatile unsigned long *)0xfffc4058)
#define Timer2_CNT (*(volatile unsigned long *)0xfffc405c)
#define Timer2_CMP0 (*(volatile unsigned long *)0xfffc4060)
#define Timer2_CMP1 (*(volatile unsigned long *)0xfffc4064)
#define Timer2_CAP0 (*(volatile unsigned long *)0xfffc4068)
#define Timer2_CAP1 (*(volatile unsigned long *)0xfffc406c)
#define CANBUS_MOD (*(volatile unsigned long *)0xfffc5000)
#define CANBUS_CMR (*(volatile unsigned long *)0xfffc5004)
#define CANBUS_SR (*(volatile unsigned long *)0xfffc5008)
#define CANBUS_IR (*(volatile unsigned long *)0xfffc500c)
#define CANBUS_IER (*(volatile unsigned long *)0xfffc5010)
#define CANBUS_BTR0 (*(volatile unsigned long *)0xfffc5018)
#define CANBUS_BTR1 (*(volatile unsigned long *)0xfffc501c)
#define CANBUS_ALC (*(volatile unsigned long *)0xfffc502c)
#define CANBUS_ECC (*(volatile unsigned long *)0xfffc5030)
#define CANBUS_EWLR (*(volatile unsigned long *)0xfffc5034)
#define CANBUS_RXERR (*(volatile unsigned long *)0xfffc5038)
#define CANBUS_TXERR (*(volatile unsigned long *)0xfffc503c)
#define CANBUS_ACR0 (*(volatile unsigned long *)0xfffc5040)
#define CANBUS_ACR1 (*(volatile unsigned long *)0xfffc5044)
#define CANBUS_ACR2 (*(volatile unsigned long *)0xfffc5048)
#define CANBUS_ACR3 (*(volatile unsigned long *)0xfffc504c)
#define CANBUS_AMR0 (*(volatile unsigned long *)0xfffc5050)
#define CANBUS_AMR1 (*(volatile unsigned long *)0xfffc5054)
#define CANBUS_AMR2 (*(volatile unsigned long *)0xfffc5058)
#define CANBUS_AMR3 (*(volatile unsigned long *)0xfffc505c)
#define CANBUS_RMC (*(volatile unsigned long *)0xfffc5074)
#define CANBUS_RBSA (*(volatile unsigned long *)0xfffc5078)
#define SSP_CTRL0 (*(volatile unsigned long *)0xfffc6000)
#define SSP_CTRL1 (*(volatile unsigned long *)0xfffc6004)
#define SSP_DR (*(volatile unsigned long *)0xfffc6008)
#define SSP_SR (*(volatile unsigned long *)0xfffc600c)
#define SSP_CPSR (*(volatile unsigned long *)0xfffc6010)
#define SSP_IIR (*(volatile unsigned long *)0xfffc6014)
#define SSP_ICR (*(volatile unsigned long *)0xfffc6014)
#define SSP_RXTO (*(volatile unsigned long *)0xfffc6018)
#define GPIO_PIDR (*(volatile unsigned long *)0xfffdb000)
#define GPIO_PJDR (*(volatile unsigned long *)0xfffdb004)
#define GPIO_PIDDR (*(volatile unsigned long *)0xfffdb008)
#define GPIO_PGDR (*(volatile unsigned long *)0xfffdc000)
#define GPIO_PHDR (*(volatile unsigned long *)0xfffdc004)
#define GPIO_PGDDR (*(volatile unsigned long *)0xfffdc008)
#define GPIO_PHDDR (*(volatile unsigned long *)0xfffdc00c)
#define GPIO_PEDR (*(volatile unsigned long *)0xfffdd000)
#define GPIO_PFDR (*(volatile unsigned long *)0xfffdd004)
#define GPIO_PEDDR (*(volatile unsigned long *)0xfffdd008)
#define GPIO_PFDDR (*(volatile unsigned long *)0xfffdd00c)
#define GPIO_PCDR (*(volatile unsigned long *)0xfffde000)
#define GPIO_PDDR (*(volatile unsigned long *)0xfffde004)
#define GPIO_PCDDR (*(volatile unsigned long *)0xfffde008)
#define GPIO_PDDDR (*(volatile unsigned long *)0xfffde00c)
#define GPIO_PADR (*(volatile unsigned long *)0xfffdf000)
#define GPIO_PBDR (*(volatile unsigned long *)0xfffdf004)
#define GPIO_PADDR (*(volatile unsigned long *)0xfffdf008)
#define GPIO_PBDDR (*(volatile unsigned long *)0xfffdf00c)
#define RTC_DR0 (*(volatile unsigned long *)0xfffe0000)
#define RTC_DR1 (*(volatile unsigned long *)0xfffe0004)
#define RTC_MR0 (*(volatile unsigned long *)0xfffe0008)
#define RTC_MR1 (*(volatile unsigned long *)0xfffe000c)
#define RTC_STAT (*(volatile unsigned long *)0xfffe0010)
#define RTC_EOI (*(volatile unsigned long *)0xfffe0010)
#define RTC_LR0 (*(volatile unsigned long *)0xfffe0014)
#define RTC_LR1 (*(volatile unsigned long *)0xfffe0018)
#define RTC_CTRL (*(volatile unsigned long *)0xfffe001c)
#define DMA0_SourceLo (*(volatile unsigned long *)0xfffe1000)
#define DMA0_SourceHi (*(volatile unsigned long *)0xfffe1004)
#define DMA0_DestLo (*(volatile unsigned long *)0xfffe1008)
#define DMA0_DestHi (*(volatile unsigned long *)0xfffe100c)
#define DMA0_Max (*(volatile unsigned long *)0xfffe1010)
#define DMA0_Ctrl (*(volatile unsigned long *)0xfffe1014)
#define DMA0_SoCurrHi (*(volatile unsigned long *)0xfffe1018)
#define DMA0_SoCurrLo (*(volatile unsigned long *)0xfffe101c)
#define DMA0_DeCurrHi (*(volatile unsigned long *)0xfffe1020)
#define DMA0_DeCurrLo (*(volatile unsigned long *)0xfffe1024)
#define DMA0_Tcnt (*(volatile unsigned long *)0xfffe1028)
#define DMA1_SourceLo (*(volatile unsigned long *)0xfffe1040)
#define DMA1_SourceHi (*(volatile unsigned long *)0xfffe1044)
#define DMA1_DestLo (*(volatile unsigned long *)0xfffe1048)
#define DMA1_DestHi (*(volatile unsigned long *)0xfffe104c)
#define DMA1_Max (*(volatile unsigned long *)0xfffe1050)
#define DMA1_Ctrl (*(volatile unsigned long *)0xfffe1054)
#define DMA1_SoCurrHi (*(volatile unsigned long *)0xfffe1058)
#define DMA1_SoCurrLo (*(volatile unsigned long *)0xfffe105c)
#define DMA1_DeCurrHi (*(volatile unsigned long *)0xfffe1060)
#define DMA1_DeCurrLo (*(volatile unsigned long *)0xfffe1064)
#define DMA1_Tcnt (*(volatile unsigned long *)0xfffe1068)
#define DMA2_SourceLo (*(volatile unsigned long *)0xfffe1080)
#define DMA2_SourceHi (*(volatile unsigned long *)0xfffe1084)
#define DMA2_DestLo (*(volatile unsigned long *)0xfffe1088)
#define DMA2_DestHi (*(volatile unsigned long *)0xfffe108c)
#define DMA2_Max (*(volatile unsigned long *)0xfffe1090)
#define DMA2_Ctrl (*(volatile unsigned long *)0xfffe1094)
#define DMA2_SoCurrHi (*(volatile unsigned long *)0xfffe1098)
#define DMA2_SoCurrLo (*(volatile unsigned long *)0xfffe109c)
#define DMA2_DeCurrHi (*(volatile unsigned long *)0xfffe10a0)
#define DMA2_DeCurrLo (*(volatile unsigned long *)0xfffe10a4)
#define DMA2_Tcnt (*(volatile unsigned long *)0xfffe10a8)
#define DMA3_SourceLo (*(volatile unsigned long *)0xfffe10c0)
#define DMA3_SourceHi (*(volatile unsigned long *)0xfffe10c4)
#define DMA3_DestLo (*(volatile unsigned long *)0xfffe10c8)
#define DMA3_DestHi (*(volatile unsigned long *)0xfffe10cc)
#define DMA3_Max (*(volatile unsigned long *)0xfffe10d0)
#define DMA3_Ctrl (*(volatile unsigned long *)0xfffe10d4)
#define DMA3_SoCurrHi (*(volatile unsigned long *)0xfffe10d8)
#define DMA3_SoCurrLo (*(volatile unsigned long *)0xfffe10dc)
#define DMA3_DeCurrHi (*(volatile unsigned long *)0xfffe10e0)
#define DMA3_DeCurrLo (*(volatile unsigned long *)0xfffe10e4)
#define DMA3_Tcnt (*(volatile unsigned long *)0xfffe10e8)
#define DMA_Mask (*(volatile unsigned long *)0xfffe10f0)
#define DMA_Clr (*(volatile unsigned long *)0xfffe10f4)
#define DMA_Status (*(volatile unsigned long *)0xfffe10f8)
#define RCPC_Ctrl (*(volatile unsigned long *)0xfffe2000)
#define RCPC_Identification (*(volatile unsigned long *)0xfffe2004)
#define RCPC_Remap (*(volatile unsigned long *)0xfffe2008)
#define RCPC_SoftReset (*(volatile unsigned long *)0xfffe200c)
#define RCPC_ResetStatus (*(volatile unsigned long *)0xfffe2010)
#define RCPC_ResetStatusClr (*(volatile unsigned long *)0xfffe2014)
#define RCPC_SysClkPrescaler (*(volatile unsigned long *)0xfffe2018)
#define RCPC_APBPeriphClkCtrl0 (*(volatile unsigned long *)0xfffe2024)
#define RCPC_APBPeriphClkCtrl1 (*(volatile unsigned long *)0xfffe2028)
#define RCPC_AHBClkCtrl (*(volatile unsigned long *)0xfffe202c)
#define RCPC_LCDPrescaler (*(volatile unsigned long *)0xfffe2040)
#define RCPC_SSPPrescaler (*(volatile unsigned long *)0xfffe2044)
#define RCPC_IntConfig (*(volatile unsigned long *)0xfffe2080)
#define RCPC_IntClear (*(volatile unsigned long *)0xfffe2084)
#define WDT_CTRL (*(volatile unsigned long *)0xfffe3000)
#define WDT_CNTR (*(volatile unsigned long *)0xfffe3004)
#define WDT_TSTR (*(volatile unsigned long *)0xfffe3008)
#define WDT_CNT0 (*(volatile unsigned long *)0xfffe300c)
#define WDT_CNT1 (*(volatile unsigned long *)0xfffe3010)
#define WDT_CNT2 (*(volatile unsigned long *)0xfffe3014)
#define WDT_CNT3 (*(volatile unsigned long *)0xfffe3018)
#define ALI_Setup (*(volatile unsigned long *)0xfffe4000)
#define ALI_CTRL (*(volatile unsigned long *)0xfffe4004)
#define ALI_Timing1 (*(volatile unsigned long *)0xfffe4008)
#define ALI_Timing2 (*(volatile unsigned long *)0xfffe400c)
#define IOCON_EBI_MUX (*(volatile unsigned long *)0xfffe5000)
#define IOCON_PD_MUX (*(volatile unsigned long *)0xfffe5004)
#define IOCON_PE_MUX (*(volatile unsigned long *)0xfffe5008)
#define IOCON_TIMER_MUX (*(volatile unsigned long *)0xfffe500c)
#define IOCON_LCD_MUX (*(volatile unsigned long *)0xfffe5010)
#define IOCON_PA_RES_MUX (*(volatile unsigned long *)0xfffe5014)
#define IOCON_PB_RES_MUX (*(volatile unsigned long *)0xfffe5018)
#define IOCON_PC_RES_MUX (*(volatile unsigned long *)0xfffe501c)
#define IOCON_PD_RES_MUX (*(volatile unsigned long *)0xfffe5020)
#define IOCON_PE_RES_MUX (*(volatile unsigned long *)0xfffe5024)
#define IOCON_ADC_MUX (*(volatile unsigned long *)0xfffe5028)
#define SMC_BCR0 (*(volatile unsigned long *)0xffff1000)
#define SMC_BCR1 (*(volatile unsigned long *)0xffff1004)
#define SMC_BCR2 (*(volatile unsigned long *)0xffff1008)
#define SMC_BCR3 (*(volatile unsigned long *)0xffff100c)
#define CLCDC_Timing0 (*(volatile unsigned long *)0xffff4000)
#define CLCDC_Timing1 (*(volatile unsigned long *)0xffff4004)
#define CLCDC_Timing2 (*(volatile unsigned long *)0xffff4008)
#define CLCDC_UPBASE (*(volatile unsigned long *)0xffff4010)
#define CLCDC_LPBASE (*(volatile unsigned long *)0xffff4014)
#define CLCDC_INTRENABLE (*(volatile unsigned long *)0xffff4018)
#define CLCDC_Ctrl (*(volatile unsigned long *)0xffff401c)
#define CLCDC_Status (*(volatile unsigned long *)0xffff4020)
#define CLCDC_Interrupt (*(volatile unsigned long *)0xffff4024)
#define CLCDC_UPCURR (*(volatile unsigned long *)0xffff4028)
#define CLCDC_LPCURR (*(volatile unsigned long *)0xffff402c)
#define CLCDC_Palette0 (*(volatile unsigned long *)0xffff4200)
#define VIC_IRQStatus (*(volatile unsigned long *)0xfffff000)
#define VIC_FIQStatus (*(volatile unsigned long *)0xfffff004)
#define VIC_RawIntr (*(volatile unsigned long *)0xfffff008)
#define VIC_IntSelect (*(volatile unsigned long *)0xfffff00c)
#define VIC_IntEnable (*(volatile unsigned long *)0xfffff010)
#define VIC_IntEnClear (*(volatile unsigned long *)0xfffff014)
#define VIC_SoftInt (*(volatile unsigned long *)0xfffff018)
#define VIC_SoftIntClear (*(volatile unsigned long *)0xfffff01c)
#define VIC_VectAddr (*(volatile unsigned long *)0xfffff030)
#define VIC_DefVecAddr (*(volatile unsigned long *)0xfffff034)
#define VIC_VectAddr0 (*(volatile unsigned long *)0xfffff100)
#define VIC_VectAddr1 (*(volatile unsigned long *)0xfffff104)
#define VIC_VectAddr2 (*(volatile unsigned long *)0xfffff108)
#define VIC_VectAddr3 (*(volatile unsigned long *)0xfffff10c)
#define VIC_VectAddr4 (*(volatile unsigned long *)0xfffff110)
#define VIC_VectAddr5 (*(volatile unsigned long *)0xfffff114)
#define VIC_VectAddr6 (*(volatile unsigned long *)0xfffff118)
#define VIC_VectAddr7 (*(volatile unsigned long *)0xfffff11c)
#define VIC_VectAddr8 (*(volatile unsigned long *)0xfffff120)
#define VIC_VectAddr9 (*(volatile unsigned long *)0xfffff124)
#define VIC_VectAddr10 (*(volatile unsigned long *)0xfffff128)
#define VIC_VectAddr11 (*(volatile unsigned long *)0xfffff12c)
#define VIC_VectAddr12 (*(volatile unsigned long *)0xfffff130)
#define VIC_VectAddr13 (*(volatile unsigned long *)0xfffff134)
#define VIC_VectAddr14 (*(volatile unsigned long *)0xfffff138)
#define VIC_VectAddr15 (*(volatile unsigned long *)0xfffff13c)
#define VIC_VectCtrl0 (*(volatile unsigned long *)0xfffff200)
#define VIC_VectCtrl1 (*(volatile unsigned long *)0xfffff204)
#define VIC_VectCtrl2 (*(volatile unsigned long *)0xfffff208)
#define VIC_VectCtrl3 (*(volatile unsigned long *)0xfffff20c)
#define VIC_VectCtrl4 (*(volatile unsigned long *)0xfffff210)
#define VIC_VectCtrl5 (*(volatile unsigned long *)0xfffff214)
#define VIC_VectCtrl6 (*(volatile unsigned long *)0xfffff218)
#define VIC_VectCtrl7 (*(volatile unsigned long *)0xfffff21c)
#define VIC_VectCtrl8 (*(volatile unsigned long *)0xfffff220)
#define VIC_VectCtrl9 (*(volatile unsigned long *)0xfffff224)
#define VIC_VectCtrl10 (*(volatile unsigned long *)0xfffff228)
#define VIC_VectCtrl11 (*(volatile unsigned long *)0xfffff22c)
#define VIC_VectCtrl12 (*(volatile unsigned long *)0xfffff230)
#define VIC_VectCtrl13 (*(volatile unsigned long *)0xfffff234)
#define VIC_VectCntl14 (*(volatile unsigned long *)0xfffff238)
#define VIC_VectCntl15 (*(volatile unsigned long *)0xfffff23c)
#endif
